//---------------------------------------------------------------------------
#ifndef optionfrmH
#define optionfrmH
//---------------------------------------------------------------------------
#include <vcl\Classes.hpp>
#include <vcl\Controls.hpp>
#include <vcl\StdCtrls.hpp>
#include <vcl\Forms.hpp>
#include <vcl\ExtCtrls.hpp>
#include <vcl\Dialogs.hpp>
#include <ComCtrls.hpp>
//---------------------------------------------------------------------------
class TOptionsfrm : public TForm
{
__published:	// IDE-managed Components
	TPanel *Panel1;
	TGroupBox *GroupBox1;
	TCheckBox *AutoBMPersonal;
	TCheckBox *AutoBMOther;
	TGroupBox *GroupBox2;
	TCheckBox *AutoVSColor;
	TShape *CurrentVSColor;
	TColorDialog *ColorDialog1;
	TButton *ChooseColorbtn;
	TPanel *Panel2;
	TButton *Button1;
	TPanel *Panel3;
	TButton *Button2;
	TLabel *Label1;
	TLabel *Label2;
	TLabel *Label3;
	TUpDown *UpDown1;
	TEdit *fontSize;
	TPanel *Panel4;
	TGroupBox *GroupBox3;
	TCheckBox *HintPopups;
	void __fastcall ChooseColorbtnClick(TObject *Sender);
	
private:	// User declarations
public:		// User declarations
	__fastcall TOptionsfrm(TComponent* Owner);
};
//---------------------------------------------------------------------------
extern TOptionsfrm *Optionsfrm;
//---------------------------------------------------------------------------
#endif
 